@@ -16,10 +16,20 @@
 #ifndef SETTINGS_HPP
 #define SETTINGS_HPP
 
+#include "edge.hpp"
+
 #include <QSize>
 
 namespace Settings {
 
+Edge::ArrowMode loadEdgeArrowMode(Edge::ArrowMode defaultMode);
+
+void saveEdgeArrowMode(Edge::ArrowMode mode);
+
+bool loadReversedEdgeDirection(bool defaultDirection);
+
+void saveReversedEdgeDirection(bool reversed);
+
 int loadGridSize();
 
 void saveGridSize(int value);
